@@ -1,10 +1,11 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-//! Traits inteded for blanket imports.
+// rustdoc-stripper-ignore-next
+//! Traits intended for blanket imports.
 
-pub use crate::auto::traits::*;
-pub use crate::pixbuf_animation::PixbufAnimationExtManual;
 #[doc(hidden)]
 pub use gio::prelude::*;
 #[doc(hidden)]
 pub use glib::prelude::*;
+
+pub use crate::{auto::traits::*, pixbuf_animation::PixbufAnimationExtManual};
